@@ -9,8 +9,10 @@ import org.baderlab.lola.view.actions.SaveLogoTreeToFile;
 import org.baderlab.lola.model.ProfileSet;
 import org.baderlab.lola.model.Profile;
 import org.baderlab.lola.model.LogoTree;
-import org.baderlab.lola.model.LogoGenerator;
 import org.baderlab.brain.util.JMultiLineToolTip;
+import org.baderlab.brain.Brain;
+import org.baderlab.brain.AminoAcidGrouping;
+import org.ccbr.bader.yeast.view.gui.misc.JCollapsablePanel;
 
 import javax.swing.*;
 import javax.swing.text.html.HTMLEditorKit;
@@ -21,6 +23,7 @@ import java.io.File;
 import java.net.URL;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeEvent;
+import java.util.ArrayList;
 
 /**
  Copyright 2007 Bader Lab
@@ -49,10 +52,10 @@ import java.beans.PropertyChangeEvent;
  */
 public class LolaMainFrame implements Runnable {
 
-    // data allProfiles - contains list of ALL OPEN profiles to be processed
+    //data allProfiles - contains list of ALL OPEN profiles to be processed
     private ProfileSet allProfiles;
 
-    // data allProfiles - contains list of SELECTED profiles to be processed
+    //data allProfiles - contains list of SELECTED profiles to be processed
     private ProfileSet selectedProfiles;
 
     //Parameters for Lola
@@ -82,13 +85,27 @@ public class LolaMainFrame implements Runnable {
     private JFormattedTextField logoTrimPercentageTextField;
     private JComboBox logoFormatComboBox;
     private JComboBox logoColorComboBox;
+    private ArrayList<JFormattedTextField> logoColorTextFields;
+    private ArrayList<JTextField> logoColorBoxes;
+    private boolean isCustomColoring;           //if true, a custom coloring scheme was created at some point
+                                                //NOTE: ONLY SET THIS FLAG ONCE - i.e. only if/when a custom coloring if FIRST set
+                                                // subsequently, don't set it back to false (if a pre-canned coloring is selected later)
+                                                // as this flag is checked to decide whether to add a "Custom" item in the coloring combo box
+    private ArrayList<JButton> logoColorButtons;
+    private int logoColorCategories;
 
     //logo tree panel
     private JPanel treePanel;
     private JTextField logoTreeTitle;
     private JTextField logoTreeOutputFilename;
+    private JFormattedTextField logoTreeLeafTrimFactor;
+    private JFormattedTextField logoTreeInternalNodeTrimFactor;
     private JButton createLogoTreeButton;
     private JButton saveLogoTreeButton;
+    private JComboBox logoTreeLeafOrderingComboBox;
+    private JComboBox groupingMethodComboBox;
+
+
 
     //profile pane
     JList profileList;
@@ -133,6 +150,16 @@ public class LolaMainFrame implements Runnable {
                 //To change body of implemented methods use File | Settings | File Templates.
             }
         });
+
+        //initialize logo colour arrays
+        for (int i = 0; i < AminoAcidGrouping.COLORING_METHODS.length; i++) {
+            
+        }
+
+        logoColorBoxes = new ArrayList<JTextField>();
+        logoColorTextFields = new ArrayList<JFormattedTextField>();
+        isCustomColoring = false;
+
     }
 
     private static final JFrame mainFrame = new JFrame(
@@ -457,11 +484,11 @@ public class LolaMainFrame implements Runnable {
 
     private JPanel getLogoTreeParamsPanel() {
 
-        //title sub-panel for logo tree settings
+        //title sub-panel for basic logo tree settings
         JPanel logoTreeOutputPanel = new JPanel();
         logoTreeOutputPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
         logoTreeOutputPanel.setLayout(new BorderLayout());
-        logoTreeOutputPanel.setBorder(BorderFactory.createTitledBorder(""));
+        logoTreeOutputPanel.setBorder(BorderFactory.createTitledBorder("Basic Options"));
 
         //output left sub-panel
         JPanel leftOutputPanel = new JPanel();
@@ -487,16 +514,11 @@ public class LolaMainFrame implements Runnable {
         String title = currentParamsCopy.getTreeTitle();
         if (title != null) logoTreeTitle.setText(title);
 
-//        leftOutputPanel.add(treeTitleLabel);
-//        leftOutputPanel.add(logoTreeTitle);
         addGridBagComponent(leftOutputPanel, treeTitleLabel, 0, 0, 1, 1,
                 GridBagConstraints.LINE_START, GridBagConstraints.NONE);
         addGridBagComponent(leftOutputPanel, logoTreeTitle, 1, 0, 1, 1,
                 GridBagConstraints.CENTER, GridBagConstraints.BOTH);
 
-//        leftOutputPanel.add(titlePanel);
-
-
         //output file name
         JPanel outputPanel = new JPanel();
         LayoutManager outputLayout = new BoxLayout(outputPanel, BoxLayout.X_AXIS);
@@ -509,8 +531,6 @@ public class LolaMainFrame implements Runnable {
         logoTreeOutputFilename.setToolTipText("Name of logo tree output file. DIRECTORY PATH IS NOT REQUIRED.   The file will be saved in the Output Directory set in the Files panel.");
         logoTreeOutputFilename.setColumns(30);
         logoTreeOutputFilename.addPropertyChangeListener("value", new textFieldChangeListener());
-//        leftOutputPanel.add(outputNameLabel);
-//        leftOutputPanel.add(logoTreeOutputFilename);
         addGridBagComponent(leftOutputPanel, outputNameLabel, 0, 1, 1, 1,
                 GridBagConstraints.LINE_START, GridBagConstraints.NONE);
         addGridBagComponent(leftOutputPanel, logoTreeOutputFilename, 1, 1, 1, 1,
@@ -539,10 +559,6 @@ public class LolaMainFrame implements Runnable {
             }
         }
         logoFormatComboBox.addActionListener(new selectLogoTreeFormatAction());
-//        logoFormatPanel.add(logoFormatLabel);
-//        logoFormatPanel.add(logoFormatComboBox);
-//        logoFormatPanel.setAlignmentX(JPanel.LEFT_ALIGNMENT);
-//        rightOutputPanel.add(logoFormatPanel);
         addGridBagComponent(leftOutputPanel, logoFormatLabel, 0, 2, 1, 1,
                 GridBagConstraints.LINE_START, GridBagConstraints.NONE);
         addGridBagComponent(leftOutputPanel, logoFormatComboBox, 1, 2, 1, 1,
@@ -568,20 +584,166 @@ public class LolaMainFrame implements Runnable {
         //the panel to return
         JPanel thePanel = new JPanel(new BorderLayout());
         thePanel.add(logoTreeOutputPanel, BorderLayout.NORTH);
+        thePanel.add(createLogoTreeAdvancedOptionsPanel(), BorderLayout.CENTER);
         thePanel.add(bottomPanel, BorderLayout.SOUTH);
         return thePanel;
 
 
     }
 
+    private JCollapsablePanel createLogoTreeAdvancedOptionsPanel() {
+
+        //main panel
+        JCollapsablePanel mainPanel = new JCollapsablePanel("Advanced Options");
+        mainPanel.setAlignmentX(JCollapsablePanel.LEFT_ALIGNMENT);
+
+
+        //sub-panel to hold all widgets
+        JPanel subPanel = new JPanel();
+//        subPanel.setLayout(new BoxLayout(subPanel, BoxLayout.Y_AXIS));
+//        subPanel.setAlignmentX(JPanel.LEFT_ALIGNMENT);
+        LayoutManager mainLayout = new GridBagLayout();
+        subPanel.setLayout(mainLayout);
+        subPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
+
+
+        //leaf node trim factor
+        JPanel leafTrimFactorPanel = new JPanel();
+        leafTrimFactorPanel.setAlignmentX(JPanel.LEFT_ALIGNMENT);
+        LayoutManager leafTrimFactorLayout = new BoxLayout(leafTrimFactorPanel, BoxLayout.X_AXIS);
+        leafTrimFactorPanel.setLayout(leafTrimFactorLayout);
+        JLabel leafTrimFactorLabel = new JLabel();
+        leafTrimFactorLabel.setText("Trim Factor for Leaf Nodes: ");
+        leafTrimFactorLabel.setAlignmentX(Component.LEFT_ALIGNMENT);
+        logoTreeLeafTrimFactor = new JFormattedTextField();
+        logoTreeLeafTrimFactor.setAlignmentX(Component.LEFT_ALIGNMENT);
+        logoTreeLeafTrimFactor.setToolTipText("Trim factor for leaf nodes");
+        logoTreeLeafTrimFactor.setColumns(5);
+        logoTreeLeafTrimFactor.addPropertyChangeListener("value", new textFieldChangeListener());
+        addGridBagComponent(subPanel, leafTrimFactorLabel, 0, 0, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, logoTreeLeafTrimFactor, 1, 0, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        logoTreeLeafTrimFactor.setText(String.valueOf(Brain.LEAFNODE_TRIM_FACTOR_DEFAULT));
+
+        //internal node trim factor
+        JPanel internalNodeTrimFactorPanel = new JPanel();
+        internalNodeTrimFactorPanel.setAlignmentX(JPanel.LEFT_ALIGNMENT);
+        LayoutManager internalNodeTrimFactorLayout = new BoxLayout(internalNodeTrimFactorPanel, BoxLayout.X_AXIS);
+        internalNodeTrimFactorPanel.setLayout(internalNodeTrimFactorLayout);
+        JLabel internalNodeTrimFactorLabel = new JLabel();
+        internalNodeTrimFactorLabel.setText("Trim Factor for Internal Nodes: ");
+        internalNodeTrimFactorLabel.setAlignmentX(Component.LEFT_ALIGNMENT);
+        logoTreeInternalNodeTrimFactor = new JFormattedTextField();
+        logoTreeInternalNodeTrimFactor.setAlignmentX(Component.LEFT_ALIGNMENT);
+        logoTreeInternalNodeTrimFactor.setToolTipText("Trim factor for leaf nodes");
+        logoTreeInternalNodeTrimFactor.setColumns(5);
+        logoTreeInternalNodeTrimFactor.addPropertyChangeListener("value", new textFieldChangeListener());
+        addGridBagComponent(subPanel, internalNodeTrimFactorLabel, 0, 1, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, logoTreeInternalNodeTrimFactor, 1, 1, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        logoTreeInternalNodeTrimFactor.setText(String.valueOf(Brain.INTERNALNODE_TRIM_FACTOR_DEFAULT));
+
+        //leaf ordering
+        JPanel leafOrderingPanel = new JPanel();
+        leafOrderingPanel.setLayout(new FlowLayout());
+        JLabel leafOrderingLabel = new JLabel("Leaf Ordering Method:");
+        logoTreeLeafOrderingComboBox = new JComboBox(Brain.LEAF_ORDERING_METHODS);
+        logoTreeLeafOrderingComboBox.setToolTipText("Algorithm used for ordering leaf nodes");
+        String currentOrdering = Brain.LEAF_ORDERING_DEFAULT;
+        if (currentOrdering != null) {
+            for (int i = 0; i < Brain.LEAF_ORDERING_METHODS.length; i++) {
+                if (currentOrdering.equalsIgnoreCase(Brain.LEAF_ORDERING_METHODS[i])) {
+                    logoTreeLeafOrderingComboBox.setSelectedIndex(i);
+                    break;
+                }
+            }
+        }
+        logoTreeLeafOrderingComboBox.addActionListener(new selectLogoTreeOrderingAction());
+        addGridBagComponent(subPanel, leafOrderingLabel, 0, 2, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, logoTreeLeafOrderingComboBox, 1, 2, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+
+        //amino acid grouping
+        JPanel groupingPanel = new JPanel();
+        groupingPanel.setLayout(new FlowLayout());
+        JLabel groupingLabel = new JLabel("Amino Acid Grouping:");
+        groupingMethodComboBox = new JComboBox(AminoAcidGrouping.GROUPING_METHODS);
+        groupingMethodComboBox.setToolTipText(getGroupingComboBoxTooltip());
+        String selectedGrouping = currentParamsCopy.getAminoAcidGrouping().getSelectedGrouping();
+        for (int i = 0; i < AminoAcidGrouping.GROUPING_METHODS.length; i++) {
+            if (selectedGrouping.equalsIgnoreCase(AminoAcidGrouping.GROUPING_METHODS[i])) {
+                groupingMethodComboBox.setSelectedIndex(i);
+                break;
+            }
+        }
+        groupingMethodComboBox.addActionListener(new selectGroupingMethodAction());
+        addGridBagComponent(subPanel, groupingLabel, 0, 3, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, groupingMethodComboBox, 1, 3, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+
+        //setup main panel
+        mainPanel.getContentPane().add(subPanel, BorderLayout.NORTH);
+        return mainPanel;
+
+
+    }
+
+    public class ColorPicker extends JFrame {
+
+      public ColorPicker() {
+        super("JColorChooser Test Frame");
+        setSize(200, 100);
+        final Container contentPane = getContentPane();
+        final JButton go = new JButton("Show JColorChooser");
+        go.addActionListener(new ActionListener() {
+          public void actionPerformed(ActionEvent e) {
+            Color c;
+            c = JColorChooser.showDialog(
+                      ((Component)e.getSource()).getParent(),
+                      "Demo", Color.blue);
+            contentPane.setBackground(c);
+          }
+        });
+        contentPane.add(go, BorderLayout.SOUTH);
+        setDefaultCloseOperation(EXIT_ON_CLOSE);
+      }
+    }
+
+    public class origColorPicker extends JFrame {
+
+      public origColorPicker() {
+        super("JColorChooser Test Frame");
+        setSize(200, 100);
+        final Container contentPane = getContentPane();
+        final JButton go = new JButton("Show JColorChooser");
+        go.addActionListener(new ActionListener() {
+          public void actionPerformed(ActionEvent e) {
+            Color c;
+            c = JColorChooser.showDialog(
+                      ((Component)e.getSource()).getParent(),
+                      "Demo", Color.blue);
+            contentPane.setBackground(c);
+          }
+        });
+        contentPane.add(go, BorderLayout.SOUTH);
+        setDefaultCloseOperation(EXIT_ON_CLOSE);
+      }
+    }
+
+
     private static void addGridBagComponent(
             Container container, Component component,
             int gridx, int gridy, int gridwidth, int gridheight, int anchor, int fill) {
 
-        Insets insets = new Insets(5,0,0,5);
+        Insets insets = new Insets(10,10,10,10);
         GridBagConstraints gbc = new GridBagConstraints(gridx, gridy, gridwidth, gridheight, 1.0, 1.0,
                 anchor, fill, insets, 1, 0);
         container.add(component, gbc);
+
     }
 
     
@@ -591,7 +753,7 @@ public class LolaMainFrame implements Runnable {
         // titled sub-panel for logo settings
         JPanel logoSettingsPanel = new JPanel();
         logoSettingsPanel.setLayout(new FlowLayout());
-        logoSettingsPanel.setBorder(BorderFactory.createTitledBorder("Logo Settings"));
+        logoSettingsPanel.setBorder(BorderFactory.createTitledBorder("Basic Options"));
 
         // left panel in logo settings
         JPanel leftSettingsPanel = new JPanel();
@@ -627,54 +789,10 @@ public class LolaMainFrame implements Runnable {
         leftSettingsPanel.add(Box.createRigidArea(new Dimension(0,5)));
         leftSettingsPanel.add(logoHeightPanel);
 
-        //logo trim percentage
-        JPanel logoTrimPercentagePanel = new JPanel(new BorderLayout());
-        JLabel logoTrimPercentageLabel = new JLabel();
-        logoTrimPercentageLabel.setText("Trim Percentage:");
-        logoTrimPercentageTextField = new JFormattedTextField() {
-            public JToolTip createToolTip() {
-                JMultiLineToolTip t = new JMultiLineToolTip();
-                t.setColumns(40);               
-                return t;
-            }
-        };
-        logoTrimPercentageTextField.setToolTipText("If columns on either end of the profile are not above this height" +
-                " (in terms of percentage of total possible column height), they will be trimmed." +
-                " This has the effect of highlighting the most informative contiguous region. The value must be" +
-                " between 0 and 1, inclusively.");
-        logoTrimPercentageTextField.setValue(currentParamsCopy.getLogoTrimPercentage());
-        logoTrimPercentageTextField.setColumns(3);
-        logoTrimPercentageTextField.addPropertyChangeListener("value", new textFieldChangeListener());
-        logoTrimPercentagePanel.add(logoTrimPercentageLabel, BorderLayout.WEST);
-        logoTrimPercentagePanel.add(logoTrimPercentageTextField, BorderLayout.EAST);
-        logoTrimPercentagePanel.setAlignmentX(JPanel.RIGHT_ALIGNMENT);
-        leftSettingsPanel.add(Box.createRigidArea(new Dimension(0,5)));
-        leftSettingsPanel.add(logoTrimPercentagePanel);
-
         // right panel in logo settings
         JPanel rightSettingsPanel = new JPanel();
         rightSettingsPanel.setLayout(new BoxLayout(rightSettingsPanel, BoxLayout.Y_AXIS));
 
-        //colour style
-        JPanel logoColorPanel = new JPanel();
-        JLabel logoColorLabel = new JLabel();
-        logoColorLabel.setText("Color Style: ");
-        logoColorComboBox = new JComboBox(LolaResources.COLOR_STYLES);
-        logoColorComboBox.setToolTipText("Residue coloring scheme");
-        String currentColor = currentParamsCopy.getLogoColorStyle();
-        if (currentColor != null) {
-            for (int i = 0; i < LolaResources.COLOR_STYLES.length; i++) {
-                if (currentColor.equalsIgnoreCase(LolaResources.COLOR_STYLES[i])) {
-                    logoColorComboBox.setSelectedIndex(i);
-                    break;
-                }
-            }
-        }
-        logoColorComboBox.addActionListener(new selectColorStyleAction());
-        logoColorPanel.add(logoColorLabel);
-        logoColorPanel.add(logoColorComboBox);
-        logoColorPanel.setAlignmentX(JPanel.LEFT_ALIGNMENT);
-        rightSettingsPanel.add(logoColorPanel);
 
         //logo format
         JPanel logoFormatPanel = new JPanel();
@@ -722,10 +840,285 @@ public class LolaMainFrame implements Runnable {
         logoSettingsPanel.add(rightSettingsPanel);
         JPanel thePanel = new JPanel(new BorderLayout());
         thePanel.add(logoSettingsPanel, BorderLayout.NORTH);
+        thePanel.add(createLogoAdvancedOptionsPanel(), BorderLayout.CENTER);
         thePanel.add(bottomPanel, BorderLayout.SOUTH);
         return thePanel;
     }
 
+
+
+
+    private JCollapsablePanel createLogoAdvancedOptionsPanel() {
+
+        //main panel
+        JCollapsablePanel mainPanel = new JCollapsablePanel("Advanced Options");
+        mainPanel.setAlignmentX(JCollapsablePanel.LEFT_ALIGNMENT);
+
+
+        //sub-panel to hold all widgets
+        JPanel subPanel = new JPanel();
+//        subPanel.setLayout(new BoxLayout(subPanel, BoxLayout.Y_AXIS));
+//        subPanel.setAlignmentX(JPanel.LEFT_ALIGNMENT);
+        LayoutManager mainLayout = new GridBagLayout();
+        subPanel.setLayout(mainLayout);
+        subPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
+
+
+        //logo trim percentage
+        JLabel logoTrimPercentageLabel = new JLabel();
+        logoTrimPercentageLabel.setText("Trim Percentage:");
+        logoTrimPercentageTextField = new JFormattedTextField() {
+            public JToolTip createToolTip() {
+                JMultiLineToolTip t = new JMultiLineToolTip();
+                t.setColumns(40);
+                return t;
+            }
+        };
+        logoTrimPercentageTextField.setToolTipText("If columns on either end of the profile are not above this height" +
+                " (in terms of percentage of total possible column height), they will be trimmed." +
+                " This has the effect of highlighting the most informative contiguous region. The value must be" +
+                " between 0 and 1, inclusively.");
+        logoTrimPercentageTextField.setValue(currentParamsCopy.getLogoTrimPercentage());
+        logoTrimPercentageTextField.setColumns(3);
+        logoTrimPercentageTextField.addPropertyChangeListener("value", new textFieldChangeListener());
+        addGridBagComponent(subPanel, logoTrimPercentageLabel, 0, 0, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, logoTrimPercentageTextField, 1, 0, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+
+
+        //color style panel
+        JPanel colorPanel = new JPanel();
+        colorPanel.setLayout(new FlowLayout());
+
+        //colour style
+        JLabel logoColorLabel = new JLabel();
+        logoColorLabel.setText("Color Style: ");
+        logoColorComboBox = new JComboBox(AminoAcidGrouping.COLORING_METHODS) {
+            public JToolTip createToolTip() {
+                JMultiLineToolTip t = new JMultiLineToolTip();
+                t.setColumns(40);
+                return t;
+            }
+        };
+        logoColorComboBox.setToolTipText(getColorComboBoxTooltip());
+        String selectedColor = currentParamsCopy.getAminoAcidGrouping().getSelectedColoring();
+        if (selectedColor != null) {
+            for (int i = 0; i < AminoAcidGrouping.COLORING_METHODS.length; i++) {
+                if (selectedColor.equalsIgnoreCase(AminoAcidGrouping.COLORING_METHODS[i])) {
+                    logoColorComboBox.setSelectedIndex(i);
+                    break;
+                }
+            }
+        }
+        logoColorComboBox.addActionListener(new selectColorStyleAction());
+        //customize color style button
+        final JButton customizeColorButton = new JButton("Customize...");
+        customizeColorButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent e) {
+                colorStyleDialog d = new colorStyleDialog(mainFrame, "Customize Color Style");
+                d.setResizable(false);
+                d.pack();
+                d.setVisible(true);
+            }
+        });
+        //put color widgets together
+        addGridBagComponent(subPanel, logoColorLabel, 0, 2, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, logoColorComboBox, 1, 2, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+        addGridBagComponent(subPanel, customizeColorButton, 2, 2, 1, 1,
+                GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+
+        //setup main panel
+        mainPanel.getContentPane().add(subPanel, BorderLayout.NORTH);
+        return mainPanel;
+
+
+    }
+
+    /*
+    Generates the tooltip text for the logo color combo box,
+    based on the descriptions and symbols defined for the selected coloring method.
+     */
+    private String getColorComboBoxTooltip() {
+        AminoAcidGrouping aaGroup = currentParamsCopy.getAminoAcidGrouping();
+        ArrayList symbolList = aaGroup.getColorSymbolList();
+        ArrayList categoryList = aaGroup.getColorCategoryList();
+
+        String tooltip = aaGroup.getSelectedDescription();
+        for (int i = 0; i < categoryList.size(); i++) {
+            tooltip += " - " + symbolList.get(i) + " (" + categoryList.get(i) + ")";
+        }
+        return tooltip;
+
+    }
+
+    /*
+    Generates the tooltip text for the amino acid grouping combo box,
+    based on the descriptions and symbols defined for the selected grouping method.
+     */
+    private String getGroupingComboBoxTooltip() {
+        AminoAcidGrouping aaGroup = currentParamsCopy.getAminoAcidGrouping();
+        ArrayList symbolList = aaGroup.getGroupList();
+        ArrayList categoryList = aaGroup.getGroupCategoryList();
+
+        String tooltip = aaGroup.getSelectedDescription();
+        for (int i = 0; i < categoryList.size(); i++) {
+            tooltip += " - " + symbolList.get(i) + " (" + categoryList.get(i) + ")";
+        }
+        return tooltip;
+
+    }
+
+    private class colorStyleDialog extends JDialog {
+
+        public colorStyleDialog(Frame frame, String s) {
+            super(frame, s);
+
+
+            //main panel
+            JPanel mainPanel = new JPanel(new BorderLayout());
+
+            //setup the color panel
+            JPanel colorPanel = new JPanel();
+            LayoutManager panelLayout = new GridBagLayout();
+            colorPanel.setLayout(panelLayout);
+            colorPanel.setAlignmentX(Component.CENTER_ALIGNMENT);
+
+
+            //column labels
+            JLabel symbolLabel = new JLabel("Group");
+            JLabel colourLabel = new JLabel("Color");
+            addGridBagComponent(colorPanel, symbolLabel, 0, 0, 1, 1,
+                    GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+            addGridBagComponent(colorPanel, colourLabel, 1, 0, 1, 1,
+                    GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+
+
+            logoColorBoxes.clear();
+            logoColorTextFields.clear();
+
+            final int originalNumberOfColors = currentParamsCopy.getAminoAcidGrouping().getNumberOfColors();
+            for (int i = 0; i < originalNumberOfColors; i++) {
+                final int j = i;
+
+                final JTextField colorBox = new JTextField();
+                logoColorBoxes.add(colorBox);
+                colorBox.setColumns(3);
+                colorBox.setEditable(false);
+                colorBox.setBackground((Color) currentParamsCopy.getAminoAcidGrouping().getColorList().get(j));
+
+                final JFormattedTextField groupTextField = new JFormattedTextField();
+                logoColorTextFields.add(groupTextField);
+                groupTextField.setColumns(10);
+                groupTextField.setValue(currentParamsCopy.getAminoAcidGrouping().getColorSymbolList().get(j));
+                groupTextField.addKeyListener(new KeyListener() {
+
+                    public void keyTyped(KeyEvent keyEvent) {
+                    }
+
+                    public void keyPressed(KeyEvent keyEvent) {
+                    }
+
+                    public void keyReleased(KeyEvent keyEvent) {
+                    }
+                });
+
+                final JButton selectColorButton = new JButton("Select...");
+                selectColorButton.addActionListener(new ActionListener() {
+                    public void actionPerformed(ActionEvent e) {
+                        Color c;
+                        c = JColorChooser.showDialog(
+                                  ((Component)e.getSource()).getParent(),
+                                  "Select Symbol Color", (Color) (currentParamsCopy.getAminoAcidGrouping().getColorList()).get(j));
+                        colorBox.setBackground(c);
+                        //currentParamsCopy.getAminoAcidGrouping().getColorList().set(j, c);
+                    }
+                });
+
+
+                //add widgets to panel
+                addGridBagComponent(colorPanel, groupTextField, 0, i+1, 1, 1,
+                        GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+                addGridBagComponent(colorPanel, colorBox, 1, i+1, 1, 1,
+                        GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+                addGridBagComponent(colorPanel, selectColorButton, 2, i+1, 1, 1,
+                        GridBagConstraints.LINE_START, GridBagConstraints.NONE);
+            }
+
+            //bottom panel with OK/Cancel buttons
+            JPanel bottomPanel = new JPanel(new FlowLayout());
+            JButton okButton = new JButton("OK");
+            okButton.addActionListener(new ActionListener() {
+                public void actionPerformed(ActionEvent actionEvent) {
+                    AminoAcidGrouping aaGrouping = currentParamsCopy.getAminoAcidGrouping();
+
+                    if (logoColorBoxes.size() == originalNumberOfColors) {
+                        //we only iterate over logoColorBoxes assuming logoColorTextFields is the same sizes
+                        for (int i = 0; i < logoColorBoxes.size(); i++) {
+                            aaGrouping.setColorSymbols(i, logoColorTextFields.get(i).getText());
+                            aaGrouping.setColor(i, logoColorBoxes.get(i).getBackground());
+                        }
+                    }
+                    if (isCustomColoring == false) {
+                        //since the custom flag is false, add a "Custom" item in the coloring combo box
+                        logoColorComboBox.addItem(new String("Custom"));
+                        logoColorComboBox.setSelectedIndex(logoColorComboBox.getModel().getSize() - 1);                        
+                        isCustomColoring = true;    //this flag indicates that a custom color was selected
+                                                    //we blindly assume here that some change was made
+                                                    //BUT this may not be the case (e.g. OK pressed without changes)
+                                                    //TODO - verify that a change was really made before setting this flag
+                    }                               
+                    setVisible(false);
+                }
+            });
+            JButton cancelButton = new JButton("Cancel");
+            cancelButton.addActionListener(new ActionListener() {
+                public void actionPerformed(ActionEvent actionEvent) {
+                    setVisible(false);
+                }
+            });
+            bottomPanel.add(okButton);
+            bottomPanel.add(cancelButton);
+
+            mainPanel.add(colorPanel, BorderLayout.NORTH);
+            mainPanel.add(bottomPanel, BorderLayout.SOUTH);
+
+
+            this.setContentPane(mainPanel);
+            this.setLocationRelativeTo(frame);
+            this.setModal(true);
+
+            //TODO - make below work i.e. if ESC is pressed, close this dialog
+            this.addKeyListener(new KeyListener() {
+                public void keyTyped(KeyEvent keyEvent) {
+                    if (keyEvent.getKeyCode() == KeyEvent.VK_ESCAPE) {
+                        setVisible(false);
+                    }
+                }
+
+                public void keyPressed(KeyEvent keyEvent) {
+                    if (keyEvent.getKeyCode() == KeyEvent.VK_ESCAPE) {
+                        setVisible(false);
+                    }
+                }
+
+                public void keyReleased(KeyEvent keyEvent) {
+                    if (keyEvent.getKeyCode() == KeyEvent.VK_ESCAPE) {
+                        setVisible(false);
+                    }
+                }
+            });
+
+
+        }
+    }
+
+
+
+
+
     /**
      * Input verifier for JTextField components.
      * TODO This input verifier doesn't seem to work - fix it.
@@ -1060,6 +1453,28 @@ public class LolaMainFrame implements Runnable {
                             currentParamsCopy.setTreeFilename(text);
                         }
                     }
+                    //logo tree leaf node trim factor
+                    else if (textField == logoTreeLeafTrimFactor) {
+                        Number value = (Number) logoTreeLeafTrimFactor.getValue();
+                        if ((value != null) && (value.doubleValue() >= Brain.LEAFNODE_TRIM_FACTOR_MIN)
+                                && (value.doubleValue() <= Brain.LEAFNODE_TRIM_FACTOR_MAX)) {
+                            currentParamsCopy.setTreeLeafTrimFactor(value.doubleValue());
+                        } else {
+                            //TODO report a visible error message if this happens
+                            logoTreeLeafTrimFactor.setValue(currentParamsCopy.getTreeLeafTrimFactor());
+                        }
+                    }
+                    //logo tree internal node trim factor
+                    else if (textField == logoTreeInternalNodeTrimFactor) {
+                        Number value = (Number) logoTreeInternalNodeTrimFactor.getValue();
+                        if ((value != null) && (value.doubleValue() >= Brain.INTERNALNODE_TRIM_FACTOR_MIN)
+                                && (value.doubleValue() <= Brain.INTERNALNODE_TRIM_FACTOR_MAX)) {
+                            currentParamsCopy.setTreeInternalNodeTrimFactor(value.doubleValue());
+                        } else {
+                            //TODO report a visible error message if this happens
+                            logoTreeInternalNodeTrimFactor.setValue(currentParamsCopy.getTreeInternalNodeTrimFactor());
+                        }
+                    }
                 }
             }
         }
@@ -1095,7 +1510,10 @@ public class LolaMainFrame implements Runnable {
             if ("comboBoxChanged".equals(event.getActionCommand())) {
                 JComboBox cb = (JComboBox) event.getSource();
                 String colorName = (String) cb.getSelectedItem();
-                currentParamsCopy.setLogoColorStyle(colorName);
+                if (!logoColorComboBox.getSelectedItem().toString().equalsIgnoreCase("Custom")) {
+                    currentParamsCopy.getAminoAcidGrouping().setColoring(colorName);
+                }
+                logoColorComboBox.setToolTipText(getColorComboBoxTooltip());
             }
         }
     }
@@ -1118,6 +1536,56 @@ public class LolaMainFrame implements Runnable {
     }
 
 
+    /**
+     * Handles choosing a logo tree ordering method
+     */
+    private class selectLogoTreeOrderingAction extends AbstractAction {
+        selectLogoTreeOrderingAction() {
+            super();
+        }
+
+        public void actionPerformed(ActionEvent event) {
+            if ("comboBoxChanged".equals(event.getActionCommand())) {
+                JComboBox cb = (JComboBox) event.getSource();
+                String methodName = (String) cb.getSelectedItem();
+                currentParamsCopy.setTreeLeafOrderingMethod(methodName);
+            }
+        }
+    }
+
+    /**
+     * Handles choosing a logo tree amino acid grouping method
+     */
+    private class selectGroupingMethodAction extends AbstractAction {
+        selectGroupingMethodAction() {
+            super();
+        }
+
+        public void actionPerformed(ActionEvent event) {
+            if ("comboBoxChanged".equals(event.getActionCommand())) {
+                JComboBox cb = (JComboBox) event.getSource();
+                String methodName = (String) cb.getSelectedItem();
+                currentParamsCopy.getAminoAcidGrouping().setGrouping(methodName);
+                groupingMethodComboBox.setToolTipText(getGroupingComboBoxTooltip());
+                
+                //changing the grouping method also resets the colour scheme (unless No Grouping or a Custom coloring was selected)
+                if (!methodName.equalsIgnoreCase(AminoAcidGrouping.GROUPING_NO_GROUPING) && !isCustomColoring) {
+
+                    //we assume here that there is a coloring method with the same name as the selected grouping method
+                    currentParamsCopy.getAminoAcidGrouping().setColoring(methodName);
+
+                    //change the selected logo coloring method in the logo color combo box
+                    for (int i = 0; i < AminoAcidGrouping.COLORING_METHODS.length; i++) {
+                        if (methodName.equalsIgnoreCase(AminoAcidGrouping.COLORING_METHODS[i])) {
+                            logoColorComboBox.setSelectedIndex(i);
+                            break;
+                        }
+                    }
+                }
+            }
+        }
+    }
+
     /**
      * Displays a file dialog with the given title and returns the selected directory.
      * @return a File object for the selected file.
